summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorNorbert Thiebaud <nthiebaud@gmail.com>2014-03-17 00:11:30 -0500
committerNorbert Thiebaud <nthiebaud@gmail.com>2014-03-20 16:11:57 -0500
commit5971a040f974dcdd0b0d8491d720fa7ad74439b4 (patch)
treec7c4a273838a908ac5e8dfb7dcd320443283aebe
parentreplace DevFontList with PhysicalFontFamilies propagate the naming change (diff)
downloadcore-5971a040f974dcdd0b0d8491d720fa7ad74439b4.tar.gz
core-5971a040f974dcdd0b0d8491d720fa7ad74439b4.zip
rename ImplDevFontList to PhysicalFontCollection
again, convergence of teh naming with what is normally used in the underlying native API, where FontFace ) FontFamily ) FontCollection Change-Id: Ieb098b782ea828a3365f00d07914b9566278caba
-rw-r--r--include/vcl/outdev.hxx4
-rw-r--r--vcl/generic/fontmanager/fontsubst.cxx6
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.cxx6
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.hxx4
-rw-r--r--vcl/generic/glyphs/glyphcache.cxx4
-rw-r--r--vcl/generic/print/genpspgraphics.cxx12
-rw-r--r--vcl/headless/svptext.cxx8
-rw-r--r--vcl/inc/generic/geninst.h4
-rw-r--r--vcl/inc/generic/genpspgraphics.h6
-rw-r--r--vcl/inc/generic/glyphcache.hxx5
-rw-r--r--vcl/inc/headless/svpgdi.hxx4
-rw-r--r--vcl/inc/outdev.h16
-rw-r--r--vcl/inc/outfont.hxx10
-rw-r--r--vcl/inc/quartz/salgdi.h6
-rw-r--r--vcl/inc/salgdi.hxx6
-rw-r--r--vcl/inc/svdata.hxx4
-rw-r--r--vcl/inc/unx/salgdi.h4
-rw-r--r--vcl/inc/win/salgdi.h4
-rw-r--r--vcl/inc/window.h4
-rw-r--r--vcl/quartz/ctfonts.cxx4
-rw-r--r--vcl/quartz/salgdi.cxx8
-rw-r--r--vcl/source/app/svmain.cxx2
-rw-r--r--vcl/source/gdi/embeddedfontshelper.cxx2
-rw-r--r--vcl/source/gdi/outdev.cxx12
-rw-r--r--vcl/source/gdi/outdev3.cxx114
-rw-r--r--vcl/source/gdi/print.cxx14
-rw-r--r--vcl/source/gdi/virdev.cxx8
-rw-r--r--vcl/source/window/window.cxx10
-rw-r--r--vcl/unx/generic/gdi/salgdi3.cxx13
-rw-r--r--vcl/win/source/gdi/salgdi3.cxx51
30 files changed, 179 insertions, 176 deletions
diff --git a/include/vcl/outdev.hxx b/include/vcl/outdev.hxx
index 2adb4d1f4a56..c53955650ad3 100644
--- a/include/vcl/outdev.hxx
+++ b/include/vcl/outdev.hxx
@@ -47,7 +47,7 @@ struct SystemGraphicsData;
struct SystemFontData;
struct SystemTextLayoutData;
class ImplFontCache;
-class ImplDevFontList;
+class PhysicalFontCollection;
class ImplGetDevFontList;
class ImplGetDevSizeList;
class ImplMultiTextLineInfo;
@@ -273,7 +273,7 @@ private:
GDIMetaFile* mpMetaFile;
mutable ImplFontEntry* mpFontEntry;
mutable ImplFontCache* mpFontCache;
- mutable ImplDevFontList* mpFontList;
+ mutable PhysicalFontCollection* mpFontCollection;
mutable ImplGetDevFontList* mpGetDevFontList;
mutable ImplGetDevSizeList* mpGetDevSizeList;
ImplObjStack* mpObjStack;
diff --git a/vcl/generic/fontmanager/fontsubst.cxx b/vcl/generic/fontmanager/fontsubst.cxx
index 44cb5a7776ac..f2f57f4a80bb 100644
--- a/vcl/generic/fontmanager/fontsubst.cxx
+++ b/vcl/generic/fontmanager/fontsubst.cxx
@@ -82,7 +82,7 @@ int SalGenericInstance::FetchFontSubstitutionFlags()
return nDisableBits;
}
-void SalGenericInstance::RegisterFontSubstitutors( ImplDevFontList* pList )
+void SalGenericInstance::RegisterFontSubstitutors( PhysicalFontCollection* pFontCollection )
{
// init font substitution defaults
int nDisableBits = 0;
@@ -103,14 +103,14 @@ void SalGenericInstance::RegisterFontSubstitutors( ImplDevFontList* pList )
if( (nDisableBits & 1) == 0 )
{
static FcPreMatchSubstititution aSubstPreMatch;
- pList->SetPreMatchHook( &aSubstPreMatch );
+ pFontCollection->SetPreMatchHook( &aSubstPreMatch );
}
// register glyph fallback substitutions (unless disabled by bit1)
if( (nDisableBits & 2) == 0 )
{
static FcGlyphFallbackSubstititution aSubstFallback;
- pList->SetFallbackHook( &aSubstFallback );
+ pFontCollection->SetFallbackHook( &aSubstFallback );
}
}
diff --git a/vcl/generic/glyphs/gcach_ftyp.cxx b/vcl/generic/glyphs/gcach_ftyp.cxx
index 93cb40ec8ac8..ea6c966e1e57 100644
--- a/vcl/generic/glyphs/gcach_ftyp.cxx
+++ b/vcl/generic/glyphs/gcach_ftyp.cxx
@@ -373,10 +373,10 @@ const unsigned char* FtFontInfo::GetTable( const char* pTag, sal_uLong* pLength
-void FtFontInfo::AnnounceFont( ImplDevFontList* pFontList )
+void FtFontInfo::AnnounceFont( PhysicalFontCollection* pFontCollection )
{
ImplFTSFontData* pFD = new ImplFTSFontData( this, maDevFontAttributes );
- pFontList->Add( pFD );
+ pFontCollection->Add( pFD );
}
@@ -442,7 +442,7 @@ void FreetypeManager::AddFontFile( const OString& rNormalizedName,
-void FreetypeManager::AnnounceFonts( ImplDevFontList* pToAdd ) const
+void FreetypeManager::AnnounceFonts( PhysicalFontCollection* pToAdd ) const
{
for( FontList::const_iterator it = maFontList.begin(); it != maFontList.end(); ++it )
{
diff --git a/vcl/generic/glyphs/gcach_ftyp.hxx b/vcl/generic/glyphs/gcach_ftyp.hxx
index a4712cc64dbc..6da2ce3b88d8 100644
--- a/vcl/generic/glyphs/gcach_ftyp.hxx
+++ b/vcl/generic/glyphs/gcach_ftyp.hxx
@@ -81,7 +81,7 @@ public:
bool IsSymbolFont() const { return maDevFontAttributes.IsSymbolFont(); }
const ImplFontAttributes& GetFontAttributes() const { return maDevFontAttributes; }
- void AnnounceFont( ImplDevFontList* );
+ void AnnounceFont( PhysicalFontCollection* );
int GetGlyphIndex( sal_UCS4 cChar ) const;
void CacheGlyphIndex( sal_UCS4 cChar, int nGI ) const;
@@ -142,7 +142,7 @@ public:
void AddFontFile( const OString& rNormalizedName,
int nFaceNum, sal_IntPtr nFontId, const ImplDevFontAttributes&);
- void AnnounceFonts( ImplDevFontList* ) const;
+ void AnnounceFonts( PhysicalFontCollection* ) const;
void ClearFontList();
ServerFont* CreateFont( const FontSelectPattern& );
diff --git a/vcl/generic/glyphs/glyphcache.cxx b/vcl/generic/glyphs/glyphcache.cxx
index 4e5e939e4bb9..7c7e2d15d8fc 100644
--- a/vcl/generic/glyphs/glyphcache.cxx
+++ b/vcl/generic/glyphs/glyphcache.cxx
@@ -161,10 +161,10 @@ void GlyphCache::AddFontFile( const OString& rNormalizedName, int nFaceNum,
}
-void GlyphCache::AnnounceFonts( ImplDevFontList* pList ) const
+void GlyphCache::AnnounceFonts( PhysicalFontCollection* pFontCollection ) const
{
if( mpFtManager )
- mpFtManager->AnnounceFonts( pList );
+ mpFtManager->AnnounceFonts( pFontCollection );
}
void GlyphCache::ClearFontCache()
diff --git a/vcl/generic/print/genpspgraphics.cxx b/vcl/generic/print/genpspgraphics.cxx
index 84eb8be57491..a0ba001d1273 100644
--- a/vcl/generic/print/genpspgraphics.cxx
+++ b/vcl/generic/print/genpspgraphics.cxx
@@ -882,12 +882,12 @@ void GenPspGraphics::SetTextColor( SalColor nSalColor )
m_pPrinterGfx->SetTextColor (aColor);
}
-bool GenPspGraphics::AddTempDevFont( ImplDevFontList*, const OUString&,const OUString& )
+bool GenPspGraphics::AddTempDevFont( PhysicalFontCollection*, const OUString&,const OUString& )
{
return false;
}
-void GenPspGraphics::GetDevFontList( ImplDevFontList *pList )
+void GenPspGraphics::GetDevFontList( PhysicalFontCollection *pFontCollection )
{
::std::list< psp::fontID > aList;
psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -897,10 +897,10 @@ void GenPspGraphics::GetDevFontList( ImplDevFontList *pList )
psp::FastPrintFontInfo aInfo;
for (it = aList.begin(); it != aList.end(); ++it)
if (rMgr.getFontFastInfo (*it, aInfo))
- AnnounceFonts( pList, aInfo );
+ AnnounceFonts( pFontCollection, aInfo );
// register platform specific font substitutions if available
- SalGenericInstance::RegisterFontSubstitutors( pList );
+ SalGenericInstance::RegisterFontSubstitutors( pFontCollection );
}
void GenPspGraphics::ClearDevFontCache()
@@ -1161,7 +1161,7 @@ namespace vcl
-void GenPspGraphics::AnnounceFonts( ImplDevFontList* pFontList, const psp::FastPrintFontInfo& aInfo )
+void GenPspGraphics::AnnounceFonts( PhysicalFontCollection* pFontCollection, const psp::FastPrintFontInfo& aInfo )
{
int nQuality = 0;
@@ -1191,7 +1191,7 @@ void GenPspGraphics::AnnounceFonts( ImplDevFontList* pFontList, const psp::FastP
ImplPspFontData* pFD = new ImplPspFontData( aInfo );
pFD->mnQuality += nQuality;
- pFontList->Add( pFD );
+ pFontCollection->Add( pFD );
}
bool GenPspGraphics::drawAlphaBitmap( const SalTwoRect&,
diff --git a/vcl/headless/svptext.cxx b/vcl/headless/svptext.cxx
index 22c786ca6a2a..f04822974a5e 100644
--- a/vcl/headless/svptext.cxx
+++ b/vcl/headless/svptext.cxx
@@ -255,7 +255,7 @@ bool SvpSalGraphics::GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabil
}
-void SvpSalGraphics::GetDevFontList( ImplDevFontList* pDevFontList )
+void SvpSalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
{
GlyphCache& rGC = SvpGlyphCache::GetInstance();
@@ -280,10 +280,10 @@ void SvpSalGraphics::GetDevFontList( ImplDevFontList* pDevFontList )
}
// announce glyphcache fonts
- rGC.AnnounceFonts( pDevFontList );
+ rGC.AnnounceFonts( pFontCollection );
// register platform specific font substitutions if available
- SalGenericInstance::RegisterFontSubstitutors( pDevFontList );
+ SalGenericInstance::RegisterFontSubstitutors( pFontCollection );
ImplGetSVData()->maGDIData.mbNativeFontConfig = true;
}
@@ -295,7 +295,7 @@ void SvpSalGraphics::ClearDevFontCache()
}
-bool SvpSalGraphics::AddTempDevFont( ImplDevFontList*,
+bool SvpSalGraphics::AddTempDevFont( PhysicalFontCollection*,
const OUString&, const OUString& )
{
return false;
diff --git a/vcl/inc/generic/geninst.h b/vcl/inc/generic/geninst.h
index 0eb72ad589d0..75a4a65dbd4b 100644
--- a/vcl/inc/generic/geninst.h
+++ b/vcl/inc/generic/geninst.h
@@ -70,7 +70,7 @@ public:
* Abstract generic class to build vclplugin's instance classes from
*/
class GenPspGraphics;
-class ImplDevFontList;
+class PhysicalFontCollection;
class VCL_DLLPUBLIC SalGenericInstance : public SalInstance
{
protected:
@@ -106,7 +106,7 @@ public:
virtual GenPspGraphics *CreatePrintGraphics() = 0;
// prolly belongs somewhere else ... just a font help
- static void RegisterFontSubstitutors( ImplDevFontList* pList );
+ static void RegisterFontSubstitutors( PhysicalFontCollection* pFontCollection );
static int FetchFontSubstitutionFlags();
protected:
diff --git a/vcl/inc/generic/genpspgraphics.h b/vcl/inc/generic/genpspgraphics.h
index 6bb32682b7ca..132b1414c9e8 100644
--- a/vcl/inc/generic/genpspgraphics.h
+++ b/vcl/inc/generic/genpspgraphics.h
@@ -64,7 +64,7 @@ public:
Ucs2UIntMap& rUnicodeEnc );
static ImplDevFontAttributes Info2DevFontAttributes( const psp::FastPrintFontInfo& );
- static void AnnounceFonts( ImplDevFontList*, const psp::FastPrintFontInfo& );
+ static void AnnounceFonts( PhysicalFontCollection*, const psp::FastPrintFontInfo& );
// overload all pure virtual methods
virtual void GetResolution( sal_Int32& rDPIX, sal_Int32& rDPIY );
@@ -87,10 +87,10 @@ public:
virtual void GetFontMetric( ImplFontMetricData*, int nFallbackLevel );
virtual const ImplFontCharMap* GetImplFontCharMap() const;
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
- virtual void GetDevFontList( ImplDevFontList* );
+ virtual void GetDevFontList( PhysicalFontCollection* );
// graphics must drop any cached font info
virtual void ClearDevFontCache();
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName );
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName );
virtual bool CreateFontSubset( const OUString& rToFile,
const PhysicalFontFace*,
diff --git a/vcl/inc/generic/glyphcache.hxx b/vcl/inc/generic/glyphcache.hxx
index 35d581706187..47188e9370c5 100644
--- a/vcl/inc/generic/glyphcache.hxx
+++ b/vcl/inc/generic/glyphcache.hxx
@@ -73,8 +73,9 @@ public:
static GlyphCache& GetInstance();
void AddFontFile( const OString& rNormalizedName,
- int nFaceNum, sal_IntPtr nFontId, const ImplDevFontAttributes&);
- void AnnounceFonts( ImplDevFontList* ) const;
+ int nFaceNum, sal_IntPtr nFontId,
+ const ImplDevFontAttributes&);
+ void AnnounceFonts( PhysicalFontCollection* ) const;
ServerFont* CacheFont( const FontSelectPattern& );
void UncacheFont( ServerFont& );
diff --git a/vcl/inc/headless/svpgdi.hxx b/vcl/inc/headless/svpgdi.hxx
index 9733e49bf18c..38506ebc7b98 100644
--- a/vcl/inc/headless/svpgdi.hxx
+++ b/vcl/inc/headless/svpgdi.hxx
@@ -152,9 +152,9 @@ public:
virtual void GetFontMetric( ImplFontMetricData*, int nFallbackLevel );
virtual const ImplFontCharMap* GetImplFontCharMap() const;
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
- virtual void GetDevFontList( ImplDevFontList* );
+ virtual void GetDevFontList( PhysicalFontCollection* );
virtual void ClearDevFontCache();
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName );
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName );
virtual bool CreateFontSubset( const OUString& rToFile,
const PhysicalFontFace*,
sal_GlyphId* pGlyphIds,
diff --git a/vcl/inc/outfont.hxx b/vcl/inc/outfont.hxx
index 01894f253baf..2afa7a2275b7 100644
--- a/vcl/inc/outfont.hxx
+++ b/vcl/inc/outfont.hxx
@@ -205,12 +205,12 @@ public: // TODO: change to private
};
-// - ImplDevFontList -
+// - PhysicalFontCollection -
// TODO: merge with ImplFontCache
// TODO: rename to LogicalFontManager
-class VCL_PLUGIN_PUBLIC ImplDevFontList
+class VCL_PLUGIN_PUBLIC PhysicalFontCollection
{
private:
friend class WinGlyphFallbackSubstititution;
@@ -224,8 +224,8 @@ private:
ImplGlyphFallbackFontSubstitution* mpFallbackHook; // device specific glyh fallback substitution
public:
- explicit ImplDevFontList();
- virtual ~ImplDevFontList();
+ explicit PhysicalFontCollection();
+ virtual ~PhysicalFontCollection();
// fill the list with device fonts
void Add( PhysicalFontFace* );
@@ -246,7 +246,7 @@ public:
void SetFallbackHook( ImplGlyphFallbackFontSubstitution* );
// misc utilities
- ImplDevFontList* Clone( bool bScalable, bool bEmbeddable ) const;
+ PhysicalFontCollection* Clone( bool bScalable, bool bEmbeddable ) const;
ImplGetDevFontList* GetDevFontList() const;
ImplGetDevSizeList* GetDevSizeList( const OUString& rFontName ) const;
diff --git a/vcl/inc/quartz/salgdi.h b/vcl/inc/quartz/salgdi.h
index f2c41eff979b..5fb10ce6bf1e 100644
--- a/vcl/inc/quartz/salgdi.h
+++ b/vcl/inc/quartz/salgdi.h
@@ -134,7 +134,7 @@ public:
bool Init( void );
void AddFont( CoreTextFontData* );
- void AnnounceFonts( ImplDevFontList& ) const;
+ void AnnounceFonts( PhysicalFontCollection& ) const;
CoreTextFontData* GetFontDataFromId( sal_IntPtr nFontId ) const;
private:
@@ -334,10 +334,10 @@ public:
virtual const ImplFontCharMap* GetImplFontCharMap() const;
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
// graphics must fill supplied font list
- virtual void GetDevFontList( ImplDevFontList* );
+ virtual void GetDevFontList( PhysicalFontCollection* );
// graphics must drop any cached font info
virtual void ClearDevFontCache();
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName );
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName );
// CreateFontSubset: a method to get a subset of glyhps of a font
// inside a new valid font file
// returns TRUE if creation of subset was successful
diff --git a/vcl/inc/salgdi.hxx b/vcl/inc/salgdi.hxx
index 69920f6dca7e..8da2d40f3d2a 100644
--- a/vcl/inc/salgdi.hxx
+++ b/vcl/inc/salgdi.hxx
@@ -32,7 +32,7 @@
#include <map>
-class ImplDevFontList;
+class PhysicalFontCollection;
class SalBitmap;
class FontSelectPattern;
class ImplFontMetricData;
@@ -241,12 +241,12 @@ public:
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const = 0;
// graphics must fill supplied font list
- virtual void GetDevFontList( ImplDevFontList* ) = 0;
+ virtual void GetDevFontList( PhysicalFontCollection* ) = 0;
// graphics must drop any cached font info
virtual void ClearDevFontCache() = 0;
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName ) = 0;
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName ) = 0;
// CreateFontSubset: a method to get a subset of glyhps of a font
// inside a new valid font file
diff --git a/vcl/inc/svdata.hxx b/vcl/inc/svdata.hxx
index 7a40ba610fc9..5795c83d327a 100644
--- a/vcl/inc/svdata.hxx
+++ b/vcl/inc/svdata.hxx
@@ -56,7 +56,7 @@ struct ImplEventHook;
class Point;
class ResMgr;
class ImplAccelManager;
-class ImplDevFontList;
+class PhysicalFontCollection;
class ImplFontCache;
class HelpTextWindow;
class ImplTBDragMgr;
@@ -168,7 +168,7 @@ struct ImplSVGDIData
Printer* mpFirstPrinter; // First Printer
Printer* mpLastPrinter; // Last Printer
ImplPrnQueueList* mpPrinterQueueList; // List of all printer queue
- ImplDevFontList* mpScreenFontList; // Screen-Font-List
+ PhysicalFontCollection* mpScreenFontList; // Screen-Font-List
ImplFontCache* mpScreenFontCache; // Screen-Font-Cache
ImplDirectFontSubstitution* mpDirectFontSubst;// Font-Substitutons defined in Tools->Options->Fonts
GraphicConverter* mpGrfConverter; // Converter for graphics
diff --git a/vcl/inc/unx/salgdi.h b/vcl/inc/unx/salgdi.h
index e6426b226231..561fdd756204 100644
--- a/vcl/inc/unx/salgdi.h
+++ b/vcl/inc/unx/salgdi.h
@@ -230,9 +230,9 @@ public:
virtual void GetFontMetric( ImplFontMetricData*, int nFallbackLevel );
virtual const ImplFontCharMap* GetImplFontCharMap() const;
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rFontCapabilities) const;
- virtual void GetDevFontList( ImplDevFontList* );
+ virtual void GetDevFontList( PhysicalFontCollection* );
virtual void ClearDevFontCache();
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName );
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName );
virtual bool CreateFontSubset( const OUString& rToFile,
const PhysicalFontFace*,
sal_GlyphId* pGlyphIDs,
diff --git a/vcl/inc/win/salgdi.h b/vcl/inc/win/salgdi.h
index 5505130f3b4f..bc76b3242d2d 100644
--- a/vcl/inc/win/salgdi.h
+++ b/vcl/inc/win/salgdi.h
@@ -312,10 +312,10 @@ public:
// get the layout capabilities of the current font
virtual bool GetImplFontCapabilities(vcl::FontCapabilities &rGetFontCapabilities) const;
// graphics must fill supplied font list
- virtual void GetDevFontList( ImplDevFontList* );
+ virtual void GetDevFontList( PhysicalFontCollection* );
// graphics must drop any cached font info
virtual void ClearDevFontCache();
- virtual bool AddTempDevFont( ImplDevFontList*, const OUString& rFileURL, const OUString& rFontName );
+ virtual bool AddTempDevFont( PhysicalFontCollection*, const OUString& rFileURL, const OUString& rFontName );
// CreateFontSubset: a method to get a subset of glyhps of a font
// inside a new valid font file
// returns TRUE if creation of subset was successful
diff --git a/vcl/inc/window.h b/vcl/inc/window.h
index 279fc27c3518..3bd78ae822f6 100644
--- a/vcl/inc/window.h
+++ b/vcl/inc/window.h
@@ -41,7 +41,7 @@ class Window;
class VclSizeGroup;
class VirtualDevice;
class Cursor;
-class ImplDevFontList;
+class PhysicalFontCollection;
class ImplFontCache;
class VCLXWindow;
class SalFrame;
@@ -135,7 +135,7 @@ struct ImplFrameData
Window* mpMouseDownWin; // last window, where MouseButtonDown() called
Window* mpFirstBackWin; // first overlap-window with saved background
::std::vector<Window *> maOwnerDrawList; // List of system windows with owner draw decoration
- ImplDevFontList* mpFontList; // Font-List for this frame
+ PhysicalFontCollection* mpFontCollection; // Font-List for this frame
ImplFontCache* mpFontCache; // Font-Cache for this frame
sal_Int32 mnDPIX; // Original Screen Resolution
sal_Int32 mnDPIY; // Original Screen Resolution
diff --git a/vcl/quartz/ctfonts.cxx b/vcl/quartz/ctfonts.cxx
index c9a2116c298b..2506d31c973d 100644
--- a/vcl/quartz/ctfonts.cxx
+++ b/vcl/quartz/ctfonts.cxx
@@ -455,11 +455,11 @@ void SystemFontList::AddFont( CoreTextFontData* pFontData )
-void SystemFontList::AnnounceFonts( ImplDevFontList& rFontList ) const
+void SystemFontList::AnnounceFonts( PhysicalFontCollection& rFontCollection ) const
{
CTFontContainer::const_iterator it = maFontContainer.begin();
for(; it != maFontContainer.end(); ++it )
- rFontList.Add( (*it).second->Clone() );
+ rFontCollection.Add( (*it).second->Clone() );
}
diff --git a/vcl/quartz/salgdi.cxx b/vcl/quartz/salgdi.cxx
index 213948da9e1d..4579729e9f13 100644
--- a/vcl/quartz/salgdi.cxx
+++ b/vcl/quartz/salgdi.cxx
@@ -401,9 +401,9 @@ static void AddLocalTempFontDirs()
AddTempFontDir( aBrandStr + "/" LIBO_SHARE_FOLDER "/fonts/truetype/" );
}
-void AquaSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
+void AquaSalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
{
- DBG_ASSERT( pFontList, "AquaSalGraphics::GetDevFontList(NULL) !");
+ DBG_ASSERT( pFontCollection, "AquaSalGraphics::GetDevFontList(NULL) !");
AddLocalTempFontDirs();
@@ -420,7 +420,7 @@ void AquaSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
pSalData->mpFontList = GetCoretextFontList();
// Copy all PhysicalFontFace objects contained in the SystemFontList
- pSalData->mpFontList->AnnounceFonts( *pFontList );
+ pSalData->mpFontList->AnnounceFonts( *pFontCollection );
}
void AquaSalGraphics::ClearDevFontCache()
@@ -432,7 +432,7 @@ void AquaSalGraphics::ClearDevFontCache()
-bool AquaSalGraphics::AddTempDevFont( ImplDevFontList*,
+bool AquaSalGraphics::AddTempDevFont( PhysicalFontCollection*,
const OUString& rFontFileURL, const OUString& /*rFontName*/ )
{
return ::AddTempDevFont(rFontFileURL);
diff --git a/vcl/source/app/svmain.cxx b/vcl/source/app/svmain.cxx
index 1c68c00df95b..6d572b416dbf 100644
--- a/vcl/source/app/svmain.cxx
+++ b/vcl/source/app/svmain.cxx
@@ -284,7 +284,7 @@ bool InitVCL()
pSVData->maAppData.mpAppFileName = new OUString( aNativeFileName );
// Initialize global data
- pSVData->maGDIData.mpScreenFontList = new ImplDevFontList;
+ pSVData->maGDIData.mpScreenFontList = new PhysicalFontCollection;
pSVData->maGDIData.mpScreenFontCache = new ImplFontCache;
pSVData->maGDIData.mpGrfConverter = new GraphicConverter;
diff --git a/vcl/source/gdi/embeddedfontshelper.cxx b/vcl/source/gdi/embeddedfontshelper.cxx
index 9d890177a2de..3e4d94694638 100644
--- a/vcl/source/gdi/embeddedfontshelper.cxx
+++ b/vcl/source/gdi/embeddedfontshelper.cxx
@@ -231,7 +231,7 @@ OUString EmbeddedFontsHelper::fontFileUrl( const OUString& familyName, FontFamil
}
bool ok = false;
SalGraphics* graphics = Application::GetDefaultDevice()->ImplGetGraphics();
- ImplDevFontList fonts;
+ PhysicalFontCollection fonts;
graphics->GetDevFontList( &fonts );
boost::scoped_ptr< ImplGetDevFontList > fontInfo( fonts.GetDevFontList());
PhysicalFontFace* selected = NULL;
diff --git a/vcl/source/gdi/outdev.cxx b/vcl/source/gdi/outdev.cxx
index 1b797a13a908..1939e2ea3111 100644
--- a/vcl/source/gdi/outdev.cxx
+++ b/vcl/source/gdi/outdev.cxx
@@ -316,7 +316,7 @@ OutputDevice::OutputDevice() :
mpMetaFile = NULL;
mpFontEntry = NULL;
mpFontCache = NULL;
- mpFontList = NULL;
+ mpFontCollection = NULL;
mpGetDevFontList = NULL;
mpGetDevSizeList = NULL;
mpObjStack = NULL;
@@ -436,13 +436,13 @@ OutputDevice::~OutputDevice()
// release ImplFontList specific to this OutputDevice
// TODO: refcount ImplFontList
- if( mpFontList
- && (mpFontList != ImplGetSVData()->maGDIData.mpScreenFontList)
+ if( mpFontCollection
+ && (mpFontCollection != ImplGetSVData()->maGDIData.mpScreenFontList)
&& (ImplGetSVData()->maGDIData.mpScreenFontList != NULL) )
{
- mpFontList->Clear();
- delete mpFontList;
- mpFontList = NULL;
+ mpFontCollection->Clear();
+ delete mpFontCollection;
+ mpFontCollection = NULL;
}
delete mpAlphaVDev;
diff --git a/vcl/source/gdi/outdev3.cxx b/vcl/source/gdi/outdev3.cxx
index 4ac03c3de9c4..e624d0bf1e1c 100644
--- a/vcl/source/gdi/outdev3.cxx
+++ b/vcl/source/gdi/outdev3.cxx
@@ -197,16 +197,16 @@ void OutputDevice::ImplClearFontData( const bool bNewFontLists )
// we need a graphics
if ( ImplGetGraphics() )
{
- if( mpFontList && mpFontList != pSVData->maGDIData.mpScreenFontList )
- mpFontList->Clear();
+ if( mpFontCollection && mpFontCollection != pSVData->maGDIData.mpScreenFontList )
+ mpFontCollection->Clear();
if( mpPDFWriter )
{
- if( mpFontList && mpFontList != pSVData->maGDIData.mpScreenFontList )
- delete mpFontList;
+ if( mpFontCollection && mpFontCollection != pSVData->maGDIData.mpScreenFontList )
+ delete mpFontCollection;
if( mpFontCache && mpFontCache != pSVData->maGDIData.mpScreenFontCache )
delete mpFontCache;
- mpFontList = 0;
+ mpFontCollection = 0;
mpFontCache = 0;
}
}
@@ -238,12 +238,12 @@ void OutputDevice::ImplRefreshFontData( const bool bNewFontLists )
{
if( mpPDFWriter )
{
- mpFontList = pSVData->maGDIData.mpScreenFontList->Clone( true, true );
+ mpFontCollection = pSVData->maGDIData.mpScreenFontList->Clone( true, true );
mpFontCache = new ImplFontCache();
}
else
{
- mpGraphics->GetDevFontList( mpFontList );
+ mpGraphics->GetDevFontList( mpFontCollection );
}
}
}
@@ -286,7 +286,7 @@ void OutputDevice::ImplUpdateAllFontData( bool bNewFontLists )
// Stupid typecast here and somewhere ((OutputDevice*)&aVDev)->, because bug in .NET2002 compiler
OutputDevice *pDevice = (OutputDevice*)pFrame;
pDevice->mpGraphics->ClearDevFontCache();
- pDevice->mpGraphics->GetDevFontList(pFrame->mpWindowImpl->mpFrameData->mpFontList);
+ pDevice->mpGraphics->GetDevFontList(pFrame->mpWindowImpl->mpFrameData->mpFontCollection);
}
}
}
@@ -531,7 +531,7 @@ Font OutputDevice::GetDefaultFont( sal_uInt16 nType, LanguageType eLang,
{
aSearchName = GetNextFontToken( aSearch, nIndex );
GetEnglishSearchFontName( aSearchName );
- PhysicalFontFamily* pFontFamily = pOutDev->mpFontList->ImplFindBySearchName( aSearchName );
+ PhysicalFontFamily* pFontFamily = pOutDev->mpFontCollection->ImplFindBySearchName( aSearchName );
if( pFontFamily )
{
AddTokenFontName( aName, pFontFamily->GetFamilyName() );
@@ -579,7 +579,7 @@ Font OutputDevice::GetDefaultFont( sal_uInt16 nType, LanguageType eLang,
// get the name of the first available font
float fExactHeight = static_cast<float>(aSize.Height());
- ImplFontEntry* pEntry = pOutDev->mpFontCache->GetFontEntry( pOutDev->mpFontList, aFont, aSize, fExactHeight );
+ ImplFontEntry* pEntry = pOutDev->mpFontCache->GetFontEntry( pOutDev->mpFontCollection, aFont, aSize, fExactHeight );
if (pEntry)
{
if( pEntry->maFontSelData.mpFontData )
@@ -1157,8 +1157,8 @@ void PhysicalFontFamily::GetFontHeights( std::set<int>& rHeights ) const
rHeights.insert( pFace->GetHeight() );
}
-void PhysicalFontFamily::UpdateCloneFontList( ImplDevFontList& rDevFontList,
- bool bScalable, bool bEmbeddable ) const
+void PhysicalFontFamily::UpdateCloneFontList( PhysicalFontCollection& rFontCollection,
+ bool bScalable, bool bEmbeddable ) const
{
for( PhysicalFontFace* pFace = mpFirst; pFace; pFace = pFace->GetNextFace() )
{
@@ -1168,11 +1168,11 @@ void PhysicalFontFamily::UpdateCloneFontList( ImplDevFontList& rDevFontList,
continue;
PhysicalFontFace* pClonedFace = pFace->Clone();
- rDevFontList.Add( pClonedFace );
+ rFontCollection.Add( pClonedFace );
}
}
-ImplDevFontList::ImplDevFontList()
+PhysicalFontCollection::PhysicalFontCollection()
: mbMatchData( false )
, mbMapNames( false )
, mpPreMatchHook( NULL )
@@ -1181,22 +1181,22 @@ ImplDevFontList::ImplDevFontList()
, mnFallbackCount( -1 )
{}
-ImplDevFontList::~ImplDevFontList()
+PhysicalFontCollection::~PhysicalFontCollection()
{
Clear();
}
-void ImplDevFontList::SetPreMatchHook( ImplPreMatchFontSubstitution* pHook )
+void PhysicalFontCollection::SetPreMatchHook( ImplPreMatchFontSubstitution* pHook )
{
mpPreMatchHook = pHook;
}
-void ImplDevFontList::SetFallbackHook( ImplGlyphFallbackFontSubstitution* pHook )
+void PhysicalFontCollection::SetFallbackHook( ImplGlyphFallbackFontSubstitution* pHook )
{
mpFallbackHook = pHook;
}
-void ImplDevFontList::Clear()
+void PhysicalFontCollection::Clear()
{
// remove fallback lists
delete[] mpFallbackList;
@@ -1217,7 +1217,7 @@ void ImplDevFontList::Clear()
mbMatchData = false;
}
-void ImplDevFontList::InitGenericGlyphFallback( void ) const
+void PhysicalFontCollection::InitGenericGlyphFallback( void ) const
{
// normalized family names of fonts suited for glyph fallback
// if a font is available related fonts can be ignored
@@ -1307,7 +1307,7 @@ void ImplDevFontList::InitGenericGlyphFallback( void ) const
mpFallbackList = pFallbackList;
}
-PhysicalFontFamily* ImplDevFontList::GetGlyphFallbackFont( FontSelectPattern& rFontSelData,
+PhysicalFontFamily* PhysicalFontCollection::GetGlyphFallbackFont( FontSelectPattern& rFontSelData,
OUString& rMissingCodes, int nFallbackLevel ) const
{
PhysicalFontFamily* pFallbackData = NULL;
@@ -1403,7 +1403,7 @@ PhysicalFontFamily* ImplDevFontList::GetGlyphFallbackFont( FontSelectPattern& rF
return pFallbackData;
}
-void ImplDevFontList::Add( PhysicalFontFace* pNewData )
+void PhysicalFontCollection::Add( PhysicalFontFace* pNewData )
{
OUString aSearchName = pNewData->GetFamilyName();
GetEnglishSearchFontName( aSearchName );
@@ -1426,12 +1426,12 @@ void ImplDevFontList::Add( PhysicalFontFace* pNewData )
}
// find the font from the normalized font family name
-PhysicalFontFamily* ImplDevFontList::ImplFindBySearchName( const OUString& rSearchName ) const
+PhysicalFontFamily* PhysicalFontCollection::ImplFindBySearchName( const OUString& rSearchName ) const
{
#ifdef DEBUG
OUString aTempName = rSearchName;
GetEnglishSearchFontName( aTempName );
- DBG_ASSERT( aTempName == rSearchName, "ImplDevFontList::ImplFindBySearchName() called with non-normalized name" );
+ DBG_ASSERT( aTempName == rSearchName, "PhysicalFontCollection::ImplFindBySearchName() called with non-normalized name" );
#endif
PhysicalFontFamilies::const_iterator it = maPhysicalFontFamilies.find( rSearchName );
@@ -1442,7 +1442,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindBySearchName( const OUString& rSear
return pFoundData;
}
-PhysicalFontFamily* ImplDevFontList::ImplFindByAliasName(const OUString& rSearchName,
+PhysicalFontFamily* PhysicalFontCollection::ImplFindByAliasName(const OUString& rSearchName,
const OUString& rShortName) const
{
// short circuit for impossible font name alias
@@ -1478,7 +1478,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindByAliasName(const OUString& rSearch
return NULL;
}
-PhysicalFontFamily* ImplDevFontList::FindFontFamily( const OUString& rFontName ) const
+PhysicalFontFamily* PhysicalFontCollection::FindFontFamily( const OUString& rFontName ) const
{
// normalize the font family name and
OUString aName = rFontName;
@@ -1487,7 +1487,7 @@ PhysicalFontFamily* ImplDevFontList::FindFontFamily( const OUString& rFontName )
return pFound;
}
-PhysicalFontFamily* ImplDevFontList::ImplFindByTokenNames(const OUString& rTokenStr) const
+PhysicalFontFamily* PhysicalFontCollection::ImplFindByTokenNames(const OUString& rTokenStr) const
{
PhysicalFontFamily* pFoundData = NULL;
@@ -1506,7 +1506,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindByTokenNames(const OUString& rToken
return pFoundData;
}
-PhysicalFontFamily* ImplDevFontList::ImplFindBySubstFontAttr( const utl::FontNameAttr& rFontAttr ) const
+PhysicalFontFamily* PhysicalFontCollection::ImplFindBySubstFontAttr( const utl::FontNameAttr& rFontAttr ) const
{
PhysicalFontFamily* pFoundData = NULL;
@@ -1539,7 +1539,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindBySubstFontAttr( const utl::FontNam
return NULL;
}
-void ImplDevFontList::InitMatchData() const
+void PhysicalFontCollection::InitMatchData() const
{
// short circuit if already done
if( mbMatchData )
@@ -1559,7 +1559,7 @@ void ImplDevFontList::InitMatchData() const
}
}
-PhysicalFontFamily* ImplDevFontList::ImplFindByAttributes( sal_uLong nSearchType,
+PhysicalFontFamily* PhysicalFontCollection::ImplFindByAttributes( sal_uLong nSearchType,
FontWeight eSearchWeight, FontWidth eSearchWidth,
FontItalic eSearchItalic, const OUString& rSearchFamilyName ) const
{
@@ -1916,7 +1916,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindByAttributes( sal_uLong nSearchType
return pFoundData;
}
-PhysicalFontFamily* ImplDevFontList::FindDefaultFont() const
+PhysicalFontFamily* PhysicalFontCollection::FindDefaultFont() const
{
// try to find one of the default fonts of the
// UNICODE, SANSSERIF, SERIF or FIXED default font lists
@@ -1967,27 +1967,27 @@ PhysicalFontFamily* ImplDevFontList::FindDefaultFont() const
return pFoundData;
}
-ImplDevFontList* ImplDevFontList::Clone( bool bScalable, bool bEmbeddable ) const
+PhysicalFontCollection* PhysicalFontCollection::Clone( bool bScalable, bool bEmbeddable ) const
{
- ImplDevFontList* pClonedList = new ImplDevFontList;
- pClonedList->mbMapNames = mbMapNames;
- pClonedList->mpPreMatchHook = mpPreMatchHook;
- pClonedList->mpFallbackHook = mpFallbackHook;
+ PhysicalFontCollection* pClonedCollection = new PhysicalFontCollection;
+ pClonedCollection->mbMapNames = mbMapNames;
+ pClonedCollection->mpPreMatchHook = mpPreMatchHook;
+ pClonedCollection->mpFallbackHook = mpFallbackHook;
// TODO: clone the config-font attributes too?
- pClonedList->mbMatchData = false;
+ pClonedCollection->mbMatchData = false;
PhysicalFontFamilies::const_iterator it = maPhysicalFontFamilies.begin();
for(; it != maPhysicalFontFamilies.end(); ++it )
{
const PhysicalFontFamily* pFontFace = (*it).second;
- pFontFace->UpdateCloneFontList( *pClonedList, bScalable, bEmbeddable );
+ pFontFace->UpdateCloneFontList( *pClonedCollection, bScalable, bEmbeddable );
}
- return pClonedList;
+ return pClonedCollection;
}
-ImplGetDevFontList* ImplDevFontList::GetDevFontList() const
+ImplGetDevFontList* PhysicalFontCollection::GetDevFontList() const
{
ImplGetDevFontList* pGetDevFontList = new ImplGetDevFontList;
@@ -2001,7 +2001,7 @@ ImplGetDevFontList* ImplDevFontList::GetDevFontList() const
return pGetDevFontList;
}
-ImplGetDevSizeList* ImplDevFontList::GetDevSizeList( const OUString& rFontName ) const
+ImplGetDevSizeList* PhysicalFontCollection::GetDevSizeList( const OUString& rFontName ) const
{
ImplGetDevSizeList* pGetDevSizeList = new ImplGetDevSizeList( rFontName );
@@ -2232,7 +2232,7 @@ ImplFontCache::~ImplFontCache()
}
}
-ImplFontEntry* ImplFontCache::GetFontEntry( ImplDevFontList* pFontList,
+ImplFontEntry* ImplFontCache::GetFontEntry( PhysicalFontCollection* pFontList,
const Font& rFont, const Size& rSize, float fExactHeight )
{
OUString aSearchName = rFont.GetName();
@@ -2242,7 +2242,7 @@ ImplFontEntry* ImplFontCache::GetFontEntry( ImplDevFontList* pFontList,
return GetFontEntry( pFontList, aFontSelData );
}
-ImplFontEntry* ImplFontCache::GetFontEntry( ImplDevFontList* pFontList,
+ImplFontEntry* ImplFontCache::GetFontEntry( PhysicalFontCollection* pFontList,
FontSelectPattern& aFontSelData )
{
// check if a directly matching logical font instance is already cached,
@@ -2378,7 +2378,7 @@ namespace
}
}
-PhysicalFontFamily* ImplDevFontList::ImplFindByFont( FontSelectPattern& rFSD ) const
+PhysicalFontFamily* PhysicalFontCollection::ImplFindByFont( FontSelectPattern& rFSD ) const
{
// give up if no fonts are available
if( !Count() )
@@ -2688,7 +2688,7 @@ PhysicalFontFamily* ImplDevFontList::ImplFindByFont( FontSelectPattern& rFSD ) c
return pFoundData;
}
-ImplFontEntry* ImplFontCache::GetGlyphFallbackFont( ImplDevFontList* pFontList,
+ImplFontEntry* ImplFontCache::GetGlyphFallbackFont( PhysicalFontCollection* pFontCollection,
FontSelectPattern& rFontSelData, int nFallbackLevel, OUString& rMissingCodes )
{
// get a candidate font for glyph fallback
@@ -2707,9 +2707,9 @@ ImplFontEntry* ImplFontCache::GetGlyphFallbackFont( ImplDevFontList* pFontList,
//sufficient heavy-weight code that's likely to undo the value of the
//optimization
if (nFallbackLevel == 1)
- pFallbackData = pFontList->FindFontFamily(OUString("EUDC"));
+ pFallbackData = pFontCollection->FindFontFamily(OUString("EUDC"));
if (!pFallbackData)
- pFallbackData = pFontList->GetGlyphFallbackFont(rFontSelData, rMissingCodes, nFallbackLevel-1);
+ pFallbackData = pFontCollection->GetGlyphFallbackFont(rFontSelData, rMissingCodes, nFallbackLevel-1);
// escape when there are no font candidates
if( !pFallbackData )
return NULL;
@@ -2719,7 +2719,7 @@ ImplFontEntry* ImplFontCache::GetGlyphFallbackFont( ImplDevFontList* pFontList,
rFontSelData.maSearchName = "";
}
- ImplFontEntry* pFallbackFont = GetFontEntry( pFontList, rFontSelData );
+ ImplFontEntry* pFallbackFont = GetFontEntry( pFontCollection, rFontSelData );
return pFallbackFont;
}
@@ -2853,15 +2853,15 @@ bool OutputDevice::ImplIsUnderlineAbove( const Font& rFont )
void OutputDevice::ImplInitFontList() const
{
- if( ! mpFontList->Count() )
+ if( ! mpFontCollection->Count() )
{
if( mpGraphics || ImplGetGraphics() )
{
SAL_INFO( "vcl.gdi", "OutputDevice::ImplInitFontList()" );
- mpGraphics->GetDevFontList( mpFontList );
+ mpGraphics->GetDevFontList( mpFontCollection );
}
}
- if( meOutDevType == OUTDEV_WINDOW && ! mpFontList->Count() )
+ if( meOutDevType == OUTDEV_WINDOW && ! mpFontCollection->Count() )
{
OUString aError( "Application error: no fonts and no vcl resource found on your system" );
ResMgr* pMgr = ImplGetResMgr();
@@ -2919,7 +2919,7 @@ bool OutputDevice::ImplNewFont() const
if( mpPDFWriter )
{
const ImplSVData* pSVData = ImplGetSVData();
- if( mpFontList == pSVData->maGDIData.mpScreenFontList
+ if( mpFontCollection == pSVData->maGDIData.mpScreenFontList
|| mpFontCache == pSVData->maGDIData.mpScreenFontCache )
const_cast<OutputDevice&>(*this).ImplUpdateFontData( true );
}
@@ -2953,7 +2953,7 @@ bool OutputDevice::ImplNewFont() const
// get font entry
ImplFontEntry* pOldEntry = mpFontEntry;
- mpFontEntry = mpFontCache->GetFontEntry( mpFontList, maFont, aSize, fExactHeight );
+ mpFontEntry = mpFontCache->GetFontEntry( mpFontCollection, maFont, aSize, fExactHeight );
if( pOldEntry )
mpFontCache->Release( pOldEntry );
@@ -5954,7 +5954,7 @@ SalLayout* OutputDevice::ImplGlyphFallbackLayout( SalLayout* pSalLayout, ImplLay
// if the system-specific glyph fallback is active
aFontSelData.mpFontEntry = mpFontEntry; // reset the fontentry to base-level
#endif
- ImplFontEntry* pFallbackFont = mpFontCache->GetGlyphFallbackFont( mpFontList,
+ ImplFontEntry* pFallbackFont = mpFontCache->GetGlyphFallbackFont( mpFontCollection,
aFontSelData, nFallbackLevel, aMissingCodes );
if( !pFallbackFont )
break;
@@ -6916,7 +6916,7 @@ int OutputDevice::GetDevFontCount() const
{
if( !mpGetDevFontList )
- mpGetDevFontList = mpFontList->GetDevFontList();
+ mpGetDevFontList = mpFontCollection->GetDevFontList();
return mpGetDevFontList->Count();
}
@@ -6956,7 +6956,7 @@ bool OutputDevice::AddTempDevFont( const OUString& rFileURL, const OUString& rFo
if( !mpGraphics && !ImplGetGraphics() )
return false;
- bool bRC = mpGraphics->AddTempDevFont( mpFontList, rFileURL, rFontName );
+ bool bRC = mpGraphics->AddTempDevFont( mpFontCollection, rFileURL, rFontName );
if( !bRC )
return false;
@@ -6973,7 +6973,7 @@ int OutputDevice::GetDevFontSizeCount( const Font& rFont ) const
delete mpGetDevSizeList;
ImplInitFontList();
- mpGetDevSizeList = mpFontList->GetDevSizeList( rFont.GetName() );
+ mpGetDevSizeList = mpFontCollection->GetDevSizeList( rFont.GetName() );
return mpGetDevSizeList->Count();
}
@@ -7011,7 +7011,7 @@ Size OutputDevice::GetDevFontSize( const Font& rFont, int nSizeIndex ) const
bool OutputDevice::IsFontAvailable( const OUString& rFontName ) const
{
- PhysicalFontFamily* pFound = mpFontList->FindFontFamily( rFontName );
+ PhysicalFontFamily* pFound = mpFontCollection->FindFontFamily( rFontName );
return (pFound != NULL);
}
diff --git a/vcl/source/gdi/print.cxx b/vcl/source/gdi/print.cxx
index ba69c1c97545..a33ba8766cd8 100644
--- a/vcl/source/gdi/print.cxx
+++ b/vcl/source/gdi/print.cxx
@@ -574,9 +574,9 @@ void Printer::ImplInit( SalPrinterQueueInfo* pInfo )
// Init data
ImplUpdatePageData();
- mpFontList = new ImplDevFontList();
+ mpFontCollection = new PhysicalFontCollection();
mpFontCache = new ImplFontCache();
- mpGraphics->GetDevFontList( mpFontList );
+ mpGraphics->GetDevFontList( mpFontCollection );
}
@@ -592,7 +592,7 @@ void Printer::ImplInitDisplay( const Window* pWindow )
mpDisplayDev = new VirtualDevice( *pWindow );
else
mpDisplayDev = new VirtualDevice();
- mpFontList = pSVData->maGDIData.mpScreenFontList;
+ mpFontCollection = pSVData->maGDIData.mpScreenFontList;
mpFontCache = pSVData->maGDIData.mpScreenFontCache;
mnDPIX = mpDisplayDev->mnDPIX;
mnDPIY = mpDisplayDev->mnDPIY;
@@ -915,9 +915,9 @@ bool Printer::SetPrinterProps( const Printer* pPrinter )
}
// clean up font list
delete mpFontCache;
- delete mpFontList;
+ delete mpFontCollection;
mpFontCache = NULL;
- mpFontList = NULL;
+ mpFontCollection = NULL;
mbInitFont = true;
mbNewFont = true;
@@ -958,9 +958,9 @@ bool Printer::SetPrinterProps( const Printer* pPrinter )
mpGetDevSizeList = NULL;
}
delete mpFontCache;
- delete mpFontList;
+ delete mpFontCollection;
mpFontCache = NULL;
- mpFontList = NULL;
+ mpFontCollection = NULL;
mbInitFont = true;
mbNewFont = true;
mpInfoPrinter = NULL;
diff --git a/vcl/source/gdi/virdev.cxx b/vcl/source/gdi/virdev.cxx
index 0cdbc0de75b4..3ef75cf9261e 100644
--- a/vcl/source/gdi/virdev.cxx
+++ b/vcl/source/gdi/virdev.cxx
@@ -137,7 +137,7 @@ void VirtualDevice::ImplInitVirDev( const OutputDevice* pOutDev,
meOutDevType = OUTDEV_VIRDEV;
mbDevOutput = true;
- mpFontList = pSVData->maGDIData.mpScreenFontList;
+ mpFontCollection = pSVData->maGDIData.mpScreenFontList;
mpFontCache = pSVData->maGDIData.mpScreenFontCache;
mnDPIX = pOutDev->mnDPIX;
mnDPIY = pOutDev->mnDPIY;
@@ -487,14 +487,14 @@ void VirtualDevice::ImplSetReferenceDevice( RefDevMode i_eRefDevMode, sal_Int32
// preserve global font lists
ImplSVData* pSVData = ImplGetSVData();
- if( mpFontList && (mpFontList != pSVData->maGDIData.mpScreenFontList) )
- delete mpFontList;
+ if( mpFontCollection && (mpFontCollection != pSVData->maGDIData.mpScreenFontList) )
+ delete mpFontCollection;
if( mpFontCache && (mpFontCache != pSVData->maGDIData.mpScreenFontCache) )
delete mpFontCache;
// get font list with scalable fonts only
ImplGetGraphics();
- mpFontList = pSVData->maGDIData.mpScreenFontList->Clone( true, false );
+ mpFontCollection = pSVData->maGDIData.mpScreenFontList->Clone( true, false );
// prepare to use new font lists
mpFontCache = new ImplFontCache();
diff --git a/vcl/source/window/window.cxx b/vcl/source/window/window.cxx
index f8bb7761fe14..7ba83e77c294 100644
--- a/vcl/source/window/window.cxx
+++ b/vcl/source/window/window.cxx
@@ -545,7 +545,7 @@ void Window::ImplUpdateGlobalSettings( AllSettings& rSettings, bool bCallHdl )
while( nIndex != -1 )
{
OUString aName( aConfigFont.getToken( 0, ';', nIndex ) );
- if ( !aName.isEmpty() && mpWindowImpl->mpFrameData->mpFontList->FindFontFamily( aName ) )
+ if ( !aName.isEmpty() && mpWindowImpl->mpFrameData->mpFontCollection->FindFontFamily( aName ) )
{
aUserInterfaceFont = aConfigFont;
break;
@@ -555,7 +555,7 @@ void Window::ImplUpdateGlobalSettings( AllSettings& rSettings, bool bCallHdl )
if ( aUserInterfaceFont.isEmpty() )
{
OUString aFallbackFont ("Andale Sans UI" );
- if ( mpWindowImpl->mpFrameData->mpFontList->FindFontFamily( aFallbackFont ) )
+ if ( mpWindowImpl->mpFrameData->mpFontCollection->FindFontFamily( aFallbackFont ) )
aUserInterfaceFont = aFallbackFont;
}
}
@@ -956,7 +956,7 @@ void Window::ImplInit( Window* pParent, WinBits nStyle, SystemParentData* pSyste
mpWindowImpl->mpFrameData->mpMouseMoveWin = NULL;
mpWindowImpl->mpFrameData->mpMouseDownWin = NULL;
mpWindowImpl->mpFrameData->mpFirstBackWin = NULL;
- mpWindowImpl->mpFrameData->mpFontList = pSVData->maGDIData.mpScreenFontList;
+ mpWindowImpl->mpFrameData->mpFontCollection = pSVData->maGDIData.mpScreenFontList;
mpWindowImpl->mpFrameData->mpFontCache = pSVData->maGDIData.mpScreenFontCache;
mpWindowImpl->mpFrameData->mnAllSaveBackSize = 0;
mpWindowImpl->mpFrameData->mnFocusId = 0;
@@ -1006,7 +1006,7 @@ void Window::ImplInit( Window* pParent, WinBits nStyle, SystemParentData* pSyste
mpWindowImpl->mpRealParent = pRealParent;
// #99318: make sure fontcache and list is available before call to SetSettings
- mpFontList = mpWindowImpl->mpFrameData->mpFontList;
+ mpFontCollection = mpWindowImpl->mpFrameData->mpFontCollection;
mpFontCache = mpWindowImpl->mpFrameData->mpFontCache;
if ( mpWindowImpl->mbFrame )
@@ -4339,7 +4339,7 @@ void Window::ImplNewInputContext()
else
aSize.Height() = (12*pFocusWin->mnDPIY)/72;
}
- pFontEntry = pFocusWin->mpFontCache->GetFontEntry( pFocusWin->mpFontList,
+ pFontEntry = pFocusWin->mpFontCache->GetFontEntry( pFocusWin->mpFontCollection,
rFont, aSize, static_cast<float>(aSize.Height()) );
if ( pFontEntry )
aNewContext.mpFont = &pFontEntry->maFontSelData;
diff --git a/vcl/unx/generic/gdi/salgdi3.cxx b/vcl/unx/generic/gdi/salgdi3.cxx
index c234973d4330..2c8949d01547 100644
--- a/vcl/unx/generic/gdi/salgdi3.cxx
+++ b/vcl/unx/generic/gdi/salgdi3.cxx
@@ -498,8 +498,9 @@ X11SalGraphics::SetTextColor( SalColor nSalColor )
-bool X11SalGraphics::AddTempDevFont( ImplDevFontList* pFontList,
- const OUString& rFileURL, const OUString& rFontName )
+bool X11SalGraphics::AddTempDevFont( PhysicalFontCollection* pFontCollection,
+ const OUString& rFileURL,
+ const OUString& rFontName )
{
// inform PSP font manager
OUString aUSystemPath;
@@ -531,7 +532,7 @@ bool X11SalGraphics::AddTempDevFont( ImplDevFontList* pFontList,
}
// announce new font to device's font list
- rGC.AnnounceFonts( pFontList );
+ rGC.AnnounceFonts( pFontCollection );
return true;
}
@@ -541,7 +542,7 @@ void X11SalGraphics::ClearDevFontCache()
rGC.ClearFontCache();
}
-void X11SalGraphics::GetDevFontList( ImplDevFontList *pList )
+void X11SalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
{
// prepare the GlyphCache using psprint's font infos
X11GlyphCache& rGC = X11GlyphCache::GetInstance();
@@ -567,10 +568,10 @@ void X11SalGraphics::GetDevFontList( ImplDevFontList *pList )
}
// announce glyphcache fonts
- rGC.AnnounceFonts( pList );
+ rGC.AnnounceFonts( pFontCollection );
// register platform specific font substitutions if available
- SalGenericInstance::RegisterFontSubstitutors( pList );
+ SalGenericInstance::RegisterFontSubstitutors( pFontCollection );
ImplGetSVData()->maGDIData.mbNativeFontConfig = true;
}
diff --git a/vcl/win/source/gdi/salgdi3.cxx b/vcl/win/source/gdi/salgdi3.cxx
index 5b3f1702ee31..b18e4e95d350 100644
--- a/vcl/win/source/gdi/salgdi3.cxx
+++ b/vcl/win/source/gdi/salgdi3.cxx
@@ -514,14 +514,13 @@ bool WinGlyphFallbackSubstititution::HasMissingChars( const PhysicalFontFace* pF
namespace
{
//used by 2-level font fallback
- PhysicalFontFamily* findDevFontListByLocale(const ImplDevFontList &rDevFontList,
- const LanguageTag& rLanguageTag )
+ PhysicalFontFamily* findDevFontListByLocale(const PhysicalFontCollection &rFontCollection,
+ const LanguageTag& rLanguageTag )
{
// get the default font for a specified locale
- const utl::DefaultFontConfiguration& rDefaults =
- utl::DefaultFontConfiguration::get();
+ const utl::DefaultFontConfiguration& rDefaults = utl::DefaultFontConfiguration::get();
const OUString aDefault = rDefaults.getUserInterfaceFont(rLanguageTag);
- return rDevFontList.ImplFindByTokenNames(aDefault);
+ return rFontCollection.ImplFindByTokenNames(aDefault);
}
}
@@ -551,34 +550,36 @@ bool WinGlyphFallbackSubstititution::FindFontSubstitute( FontSelectPattern& rFon
// first level fallback:
// try use the locale specific default fonts defined in VCL.xcu
- const ImplDevFontList* pDevFontList = ImplGetSVData()->maGDIData.mpScreenFontList;
- /*const*/ PhysicalFontFamily* pDevFont = findDevFontListByLocale(*pDevFontList, aLanguageTag);
- if( pDevFont )
+ const PhysicalFontCollection* pFontCollection = ImplGetSVData()->maGDIData.mpScreenFontList;
+ /*const*/ PhysicalFontFamily* pFontFamily = findDevFontListByLocale(*pFontCollection, aLanguageTag);
+ if( pFontFamily )
{
- const PhysicalFontFace* pFace = pDevFont->FindBestFontFace( rFontSelData );
+ const PhysicalFontFace* pFace = pFontFamily->FindBestFontFace( rFontSelData );
if( HasMissingChars( pFace, rMissingChars ) )
{
- rFontSelData.maSearchName = pDevFont->GetSearchName();
+ rFontSelData.maSearchName = pFontFamily->GetSearchName();
return true;
}
}
// are the missing characters symbols?
- pDevFont = pDevFontList->ImplFindByAttributes( IMPL_FONT_ATTR_SYMBOL,
- rFontSelData.GetWeight(), rFontSelData.GetWidthType(),
- rFontSelData.GetSlant(), rFontSelData.maSearchName );
- if( pDevFont )
- {
- const PhysicalFontFace* pFace = pDevFont->FindBestFontFace( rFontSelData );
+ pFontFamily = pFontCollection->ImplFindByAttributes( IMPL_FONT_ATTR_SYMBOL,
+ rFontSelData.GetWeight(),
+ rFontSelData.GetWidthType(),
+ rFontSelData.GetSlant(),
+ rFontSelData.maSearchName );
+ if( pFontFamily )
+ {
+ const PhysicalFontFace* pFace = pFontFamily->FindBestFontFace( rFontSelData );
if( HasMissingChars( pFace, rMissingChars ) )
{
- rFontSelData.maSearchName = pDevFont->GetSearchName();
+ rFontSelData.maSearchName = pFontFamily->GetSearchName();
return true;
}
}
// last level fallback, check each font type face one by one
- ImplGetDevFontList* pTestFontList = pDevFontList->GetDevFontList();
+ ImplGetDevFontList* pTestFontList = pFontCollection->GetDevFontList();
// limit the count of fonts to be checked to prevent hangs
static const int MAX_GFBFONT_COUNT = 600;
int nTestFontCount = pTestFontList->Count();
@@ -606,7 +607,7 @@ bool WinGlyphFallbackSubstititution::FindFontSubstitute( FontSelectPattern& rFon
struct ImplEnumInfo
{
HDC mhDC;
- ImplDevFontList* mpList;
+ PhysicalFontCollection* mpList;
OUString* mpName;
LOGFONTA* mpLogFontA;
LOGFONTW* mpLogFontW;
@@ -2105,7 +2106,7 @@ static bool ImplGetFontAttrFromFile( const OUString& rFontFileURL,
-bool WinSalGraphics::AddTempDevFont( ImplDevFontList* pFontList,
+bool WinSalGraphics::AddTempDevFont( PhysicalFontCollection* pFontCollection,
const OUString& rFontFileURL, const OUString& rFontName )
{
SAL_INFO( "vcl.gdi", "WinSalGraphics::AddTempDevFont(): " << OUStringToOString( rFontFileURL, RTL_TEXTENCODING_UTF8 ).getStr() );
@@ -2157,13 +2158,13 @@ bool WinSalGraphics::AddTempDevFont( ImplDevFontList* pFontList,
sal::static_int_cast<BYTE>(nPreferredCharSet),
sal::static_int_cast<BYTE>(TMPF_VECTOR|TMPF_TRUETYPE) );
pFontData->SetFontId( reinterpret_cast<sal_IntPtr>(pFontData) );
- pFontList->Add( pFontData );
+ pFontCollection->Add( pFontData );
return true;
}
-void WinSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
+void WinSalGraphics::GetDevFontList( PhysicalFontCollection* pFontCollection )
{
// make sure all fonts are registered at least temporarily
static bool bOnce = true;
@@ -2204,7 +2205,7 @@ void WinSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
osl::FileStatus aFileStatus( osl_FileStatus_Mask_FileURL );
rcOSL = aDirItem.getFileStatus( aFileStatus );
if ( rcOSL == osl::FileBase::E_None )
- AddTempDevFont( pFontList, aFileStatus.getFileURL(), aEmptyString );
+ AddTempDevFont( pFontCollection, aFileStatus.getFileURL(), aEmptyString );
}
delete mpFontAttrCache; // destructor rewrites the cache file if needed
@@ -2214,7 +2215,7 @@ void WinSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
ImplEnumInfo aInfo;
aInfo.mhDC = getHDC();
- aInfo.mpList = pFontList;
+ aInfo.mpList = pFontCollection;
aInfo.mpName = NULL;
aInfo.mpLogFontA = NULL;
aInfo.mpLogFontW = NULL;
@@ -2255,7 +2256,7 @@ void WinSalGraphics::GetDevFontList( ImplDevFontList* pFontList )
// set glyph fallback hook
static WinGlyphFallbackSubstititution aSubstFallback( getHDC() );
- pFontList->SetFallbackHook( &aSubstFallback );
+ pFontCollection->SetFallbackHook( &aSubstFallback );
}
void WinSalGraphics::ClearDevFontCache()
diff --git a/vcl/inc/outdev.h b/vcl/inc/outdev.h
index f9b3710097ed..383bb71a7ca5 100644
--- a/vcl/inc/outdev.h
+++ b/vcl/inc/outdev.h
@@ -61,11 +61,11 @@ public:
void GetFontHeights( std::set<int>& rHeights ) const;
void UpdateDevFontList( ImplGetDevFontList& ) const;
- void UpdateCloneFontList( ImplDevFontList&,
+ void UpdateCloneFontList( PhysicalFontCollection&,
bool bScalable, bool bEmbeddable ) const;
private:
-friend class ImplDevFontList; // TODO: remove soon
+friend class PhysicalFontCollection; // TODO: remove soon
PhysicalFontFace* mpFirst; // linked list of physical font faces
OUString maName; // Fontname (original font family name)
OUString maSearchName; // normalized font family name
@@ -80,8 +80,8 @@ friend class ImplDevFontList; // TODO: remove soon
int mnMinQuality; // quality of the worst font face
};
-// an ImplGetDevFontList is created by an ImplDevFontList
-// it becomes invalid when original ImplDevFontList is modified
+// an ImplGetDevFontList is created by an PhysicalFontCollection
+// it becomes invalid when original PhysicalFontCollection is modified
class ImplGetDevFontList
{
private:
@@ -174,7 +174,7 @@ public:
virtual bool FindFontSubstitute( FontSelectPattern&, OUString& rMissingCodes ) const = 0;
};
// TODO: closely couple with ImplDevFontList
class ImplFontCache
{
@@ -192,10 +192,10 @@ public:
ImplFontCache();
~ImplFontCache();
- ImplFontEntry* GetFontEntry( ImplDevFontList*,
+ ImplFontEntry* GetFontEntry( PhysicalFontCollection*,
const Font&, const Size& rPixelSize, float fExactHeight);
- ImplFontEntry* GetFontEntry( ImplDevFontList*, FontSelectPattern& );
- ImplFontEntry* GetGlyphFallbackFont( ImplDevFontList*, FontSelectPattern&,
+ ImplFontEntry* GetFontEntry( PhysicalFontCollection*, FontSelectPattern& );
+ ImplFontEntry* GetGlyphFallbackFont( PhysicalFontCollection*, FontSelectPattern&,
int nFallbackLevel, OUString& rMissingCodes );
void Release( ImplFontEntry* );
void Invalidate();
@@ -174,7 +174,7 @@ public:
virtual bool FindFontSubstitute( FontSelectPattern&, OUString& rMissingCodes ) const = 0;
};
-// TODO: closely couple with ImplDevFontList
+// TODO: closely couple with PhysicalFontCollection
class ImplFontCache
{